==> org-lsst-ccs-subsystem-refrig-buses-4.0.0-sources.jar: org/lsst/ccs/subsystem/refrig/data/ColdCompState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.util.ArrayList;
import java.util.List;

/**
 *  Contains the state of a cold compressor.
 *
 *  The order of the elements in each list determines the order they appear in the GUI
 *
 *  @author Owen Saxton
 */
public class ColdCompState extends CompState {

    public static final List<Integer> SWITCHES = new ArrayList<>();
    static {
        SWITCHES.add(SW_ENABLE);
        SWITCHES.add(SW_LIGHTS);
    }
    public static final List<Integer> LATCHES = new ArrayList<>();
    static {
        LATCHES.add(LATCH_DISCHARGE_TEMP);
        LATCHES.add(LATCH_DISCHARGE_PRESS);
        LATCHES.add(LATCH_SUCTION_TEMP);
        LATCHES.add(LATCH_LIQUID_TEMP);
        LATCHES.add(LATCH_POWER);
        LATCHES.add(LATCH_SENSORS_VALID);
        LATCHES.add(LATCH_SMOKE_DETC);
        LATCHES.add(LATCH_EXT_PERMIT);
    }
    public static final List<Integer> CONDITIONS = new ArrayList<>();
    static {
        CONDITIONS.add(COND_KEYSWITCH_ON);
        CONDITIONS.add(COND_CMP_ENABLED);
        CONDITIONS.add(COND_CMP_WAITING);
        CONDITIONS.add(COND_CMP_POWERED);
        CONDITIONS.add(COND_DISC_TEMP_VALID);
        CONDITIONS.add(COND_DISC_PRESS_VALID);
        CONDITIONS.add(COND_SUCT_TEMP_VALID);
        CONDITIONS.add(COND_SUCT_PRESS_VALID);
        CONDITIONS.add(COND_LIQD_TEMP_VALID);
        CONDITIONS.add(COND_CURRENT_VALID);
        CONDITIONS.add(COND_VOLTAGE_VALID);
        CONDITIONS.add(COND_CURR_SENSOR_ERR);
        CONDITIONS.add(COND_LATCHES_CLEAR);
        CONDITIONS.add(COND_POWER_LED);
    }

    public ColdCompState() {
        super(TYPE_COLD);
    }

    private static final long serialVersionUID = -3018569415466122938L;
}

==> org-lsst-ccs-subsystem-refrig-buses-4.0.2-sources.jar: org/lsst/ccs/subsystem/refrig/data/ColdCompState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.util.ArrayList;
import java.util.List;

/**
 *  Contains the state of a cold compressor.
 *
 *  The order of the elements in each list determines the order they appear in the GUI
 *
 *  @author Owen Saxton
 */
public class ColdCompState extends CompState {

    public static final List<Integer> SWITCHES = new ArrayList<>();
    static {
        SWITCHES.add(SW_ENABLE);
        SWITCHES.add(SW_LIGHTS);
    }
    public static final List<Integer> LATCHES = new ArrayList<>();
    static {
        LATCHES.add(LATCH_DISCHARGE_TEMP);
        LATCHES.add(LATCH_DISCHARGE_PRESS);
        LATCHES.add(LATCH_SUCTION_TEMP);
        LATCHES.add(LATCH_LIQUID_TEMP);
        LATCHES.add(LATCH_POWER);
        LATCHES.add(LATCH_SENSORS_VALID);
        LATCHES.add(LATCH_SMOKE_DETC);
        LATCHES.add(LATCH_EXT_PERMIT);
    }
    public static final List<Integer> CONDITIONS = new ArrayList<>();
    static {
        CONDITIONS.add(COND_KEYSWITCH_ON);
        CONDITIONS.add(COND_CMP_ENABLED);
        CONDITIONS.add(COND_CMP_WAITING);
        CONDITIONS.add(COND_CMP_POWERED);
        CONDITIONS.add(COND_DISC_TEMP_VALID);
        CONDITIONS.add(COND_DISC_PRESS_VALID);
        CONDITIONS.add(COND_SUCT_TEMP_VALID);
        CONDITIONS.add(COND_SUCT_PRESS_VALID);
        CONDITIONS.add(COND_LIQD_TEMP_VALID);
        CONDITIONS.add(COND_CURRENT_VALID);
        CONDITIONS.add(COND_VOLTAGE_VALID);
        CONDITIONS.add(COND_CURR_SENSOR_ERR);
        CONDITIONS.add(COND_LATCHES_CLEAR);
        CONDITIONS.add(COND_POWER_LED);
    }
    public static final List<Integer> SW_CONDITIONS = new ArrayList<>();
    static {
        SW_CONDITIONS.add(SWC_CMPR_POWER);
        SW_CONDITIONS.add(SWC_DISC_PRESS);
        SW_CONDITIONS.add(SWC_DISC_TEMP);
        SW_CONDITIONS.add(SWC_SUCT_TEMP);
        SW_CONDITIONS.add(SWC_PLATE_TEMP);
        SW_CONDITIONS.add(SWC_LIQUID_TEMP);
    }

    public ColdCompState() {
        super(TYPE_COLD);
    }

    private static final long serialVersionUID = 1216381263116312937L;
}
